========================
Murano CLI Documentation
========================

In this section you will find information on Murano's command line
interface.

.. toctree::
   :maxdepth: 1

   murano-status
